@@ -23,7 +23,6 @@ from __future__ import division
 
 import time
 import pytest
-from .fakesanlock import FakeSanlock
 from vdsm.common import concurrent
 from vdsm.storage import clusterlock
 from vdsm.storage import constants as sc
@@ -39,95 +38,83 @@ LEASE = clusterlock.Lease("SDM", "leases", 1024**2)
 
 
 @pytest.fixture
-def fake_sanlock(monkeypatch):
-    fs = FakeSanlock()
-    monkeypatch.setattr(clusterlock, "sanlock", fs)
-    # FakeSanlock does not implement the depracated init_resource, so we will
-    # create the resource using write_resource, so we can test acquire and
-    # release.
-    fs.write_resource(LS_NAME, LEASE.name, [(LEASE.path, LEASE.offset)])
-    return fs
+def lock():
+    sanlock = clusterlock.SANLock(LS_NAME, LS_PATH, LEASE)
+    sanlock.initLock(LEASE)
+    return sanlock
 
 
-def test_acquire_host_id_sync(fake_sanlock):
-    sl = clusterlock.SANLock(LS_NAME, LS_PATH, LEASE)
-    sl.acquireHostId(HOST_ID, async=False)
+def test_acquire_host_id_sync(fake_sanlock, lock):
+    lock.acquireHostId(HOST_ID, wait=True)
     acquired = fake_sanlock.inq_lockspace(LS_NAME, HOST_ID, LS_PATH, LS_OFF)
     assert acquired is True
 
 
-def test_acquire_host_id_async(fake_sanlock):
-    sl = clusterlock.SANLock(LS_NAME, LS_PATH, LEASE)
-    sl.acquireHostId(HOST_ID, async=True)
+def test_acquire_host_id_async(fake_sanlock, lock):
+    lock.acquireHostId(HOST_ID, wait=False)
     acquired = fake_sanlock.inq_lockspace(LS_NAME, HOST_ID, LS_PATH, LS_OFF)
     assert acquired is None
 
 
-def test_release_host_id_sync(fake_sanlock):
-    sl = clusterlock.SANLock(LS_NAME, LS_PATH, LEASE)
-    sl.acquireHostId(HOST_ID, async=False)
-    sl.releaseHostId(HOST_ID, async=False, unused=False)
+def test_release_host_id_sync(fake_sanlock, lock):
+    lock.acquireHostId(HOST_ID, wait=True)
+    lock.releaseHostId(HOST_ID, wait=True, unused=False)
     acquired = fake_sanlock.inq_lockspace(LS_NAME, HOST_ID, LS_PATH, LS_OFF)
     assert acquired is False
 
 
-def test_release_host_id_async(fake_sanlock):
-    sl = clusterlock.SANLock(LS_NAME, LS_PATH, LEASE)
-    sl.acquireHostId(HOST_ID, async=False)
-    sl.releaseHostId(HOST_ID, async=True, unused=False)
+def test_release_host_id_async(fake_sanlock, lock):
+    lock.acquireHostId(HOST_ID, wait=True)
+    lock.releaseHostId(HOST_ID, wait=False, unused=False)
     acquired = fake_sanlock.inq_lockspace(LS_NAME, HOST_ID, LS_PATH, LS_OFF)
     assert acquired is None
 
 
-def test_acquire(fake_sanlock):
-    sl = clusterlock.SANLock(LS_NAME, LS_PATH, LEASE)
-    sl.acquireHostId(HOST_ID, async=False)
-    sl.acquire(HOST_ID, LEASE)
+def test_acquire(fake_sanlock, lock):
+    lock.acquireHostId(HOST_ID, wait=True)
+    lock.acquire(HOST_ID, LEASE)
     res = fake_sanlock.read_resource(LEASE.path, LEASE.offset)
     assert res["acquired"]
 
 
-def test_release(fake_sanlock):
-    sl = clusterlock.SANLock(LS_NAME, LS_PATH, LEASE)
-    sl.acquireHostId(HOST_ID, async=False)
-    sl.acquire(HOST_ID, LEASE)
-    sl.release(LEASE)
+def test_release(fake_sanlock, lock):
+    lock.acquireHostId(HOST_ID, wait=True)
+    lock.acquire(HOST_ID, LEASE)
+    lock.release(LEASE)
     res = fake_sanlock.read_resource(LEASE.path, LEASE.offset)
     assert not res["acquired"]
 
 
-def test_acquire_wait_until_host_id_is_acquired(fake_sanlock):
-    sl = clusterlock.SANLock(LS_NAME, LS_PATH, LEASE)
+def test_acquire_wait_until_host_id_is_acquired(fake_sanlock, lock):
     # Starts async host id acquire...
-    sl.acquireHostId(HOST_ID, async=True)
+    lock.acquireHostId(HOST_ID, wait=False)
 
     def monitor():
         # Simulate the domain monitor checking if host id was acquire every 10
         # seconds...
         for i in range(3):
-            sl.hasHostId(HOST_ID)
+            lock.hasHostId(HOST_ID)
             time.sleep(0.3)
 
         fake_sanlock.complete_async(LS_NAME)
         # Discover that host id was acquired, and wake up threads waiting on
         # acquire().
-        sl.hasHostId(HOST_ID)
+        lock.hasHostId(HOST_ID)
 
     t = concurrent.thread(monitor)
     t.start()
     try:
         # Acquire should wait until host id acquire is completed.
-        sl.acquire(HOST_ID, LEASE)
+        lock.acquire(HOST_ID, LEASE)
         res = fake_sanlock.read_resource(LEASE.path, LEASE.offset)
     finally:
         t.join()
     assert res["acquired"]
 
 
-def test_acquire_after_inq_lockspace_failure(fake_sanlock):
-    sl = clusterlock.SANLock(LS_NAME, LS_PATH, LEASE)
+def test_acquire_after_inq_lockspace_failure(fake_sanlock, lock):
     # Starts async host id acquire...
-    sl.acquireHostId(HOST_ID, async=True)
+    lock.acquireHostId(HOST_ID, wait=False)
 
     def monitor():
         time.sleep(0.3)
@@ -135,7 +122,7 @@ def test_acquire_after_inq_lockspace_failure(fake_sanlock):
         # Simulate failing hasHostId...
         fake_sanlock.errors["inq_lockspace"] = fake_sanlock.SanlockException(1)
         try:
-            sl.hasHostId(HOST_ID)
+            lock.hasHostId(HOST_ID)
         except fake_sanlock.SanlockException:
             pass
 
@@ -144,41 +131,38 @@ def test_acquire_after_inq_lockspace_failure(fake_sanlock):
         # Make the next try successful
         fake_sanlock.complete_async(LS_NAME)
         del fake_sanlock.errors["inq_lockspace"]
-        sl.hasHostId(HOST_ID)
+        lock.hasHostId(HOST_ID)
 
     t = concurrent.thread(monitor)
     t.start()
     try:
         # Acquire should wait until host id acquire is completed.
-        sl.acquire(HOST_ID, LEASE)
+        lock.acquire(HOST_ID, LEASE)
         res = fake_sanlock.read_resource(LEASE.path, LEASE.offset)
     finally:
         t.join()
     assert res["acquired"]
 
 
-def test_acquire_timeout_waiting_for_host_id(fake_sanlock, monkeypatch):
+def test_acquire_timeout_waiting_for_host_id(fake_sanlock, lock, monkeypatch):
     # Make this test fast
-    monkeypatch.setattr(clusterlock.SANLock, "ACQUIRE_HOST_ID_TIMEOUT", 0.0)
-    sl = clusterlock.SANLock(LS_NAME, LS_PATH, LEASE)
+    monkeypatch.setattr(lock, "ACQUIRE_HOST_ID_TIMEOUT", 0.0)
     # Starts async host id acquire that will never complete...
-    sl.acquireHostId(HOST_ID, async=True)
+    lock.acquireHostId(HOST_ID, wait=False)
     # Acquire should time out
-    pytest.raises(se.AcquireHostIdFailure, sl.acquire, HOST_ID, LEASE)
+    pytest.raises(se.AcquireHostIdFailure, lock.acquire, HOST_ID, LEASE)
 
 
-def test_acquire_after_relases_host_id(fake_sanlock):
-    sl = clusterlock.SANLock(LS_NAME, LS_PATH, LEASE)
-    sl.acquireHostId(HOST_ID, async=False)
-    sl.releaseHostId(HOST_ID, async=False, unused=False)
-    pytest.raises(concurrent.InvalidEvent, sl.acquire, HOST_ID, LEASE)
+def test_acquire_after_relases_host_id(fake_sanlock, lock):
+    lock.acquireHostId(HOST_ID, wait=True)
+    lock.releaseHostId(HOST_ID, wait=True, unused=False)
+    pytest.raises(concurrent.InvalidEvent, lock.acquire, HOST_ID, LEASE)
 
 
-def test_inquire_lease(fake_sanlock):
-    sl = clusterlock.SANLock(LS_NAME, LS_PATH, LEASE)
-    sl.acquireHostId(HOST_ID, async=False)
-    sl.acquire(HOST_ID, LEASE)
-    version, owner = sl.inquire(LEASE)
+def test_inquire_lease(fake_sanlock, lock):
+    lock.acquireHostId(HOST_ID, wait=True)
+    lock.acquire(HOST_ID, LEASE)
+    version, owner = lock.inquire(LEASE)
     assert version == 0
     assert owner == HOST_ID
 
@@ -190,50 +174,46 @@ def test_inquire_lease(fake_sanlock):
     (sanlock.HOST_FREE, None),
     (sanlock.HOST_DEAD, None)
 ])
-def test_inquire_owner_status(fake_sanlock, status, expected_owner_id):
-    sl = clusterlock.SANLock(LS_NAME, LS_PATH, LEASE)
-    sl.acquireHostId(HOST_ID, async=False)
-    sl.acquire(HOST_ID, LEASE)
+def test_inquire_owner_status(fake_sanlock, lock, status, expected_owner_id):
+    lock.acquireHostId(HOST_ID, wait=True)
+    lock.acquire(HOST_ID, LEASE)
     # we are simulating another host inquiring the lease
     fake_sanlock.hosts[HOST_ID]["flags"] = status
-    version, owner = sl.inquire(LEASE)
+    version, owner = lock.inquire(LEASE)
     assert version == 0
     assert owner == expected_owner_id
 
 
-def test_inquire_owner_reconnected(fake_sanlock):
-    sl = clusterlock.SANLock(LS_NAME, LS_PATH, LEASE)
+def test_inquire_owner_reconnected(fake_sanlock, lock):
     # This simulates a host reconnecting to the lockspace.
     # The lease should have no owner since the generation
     # increases each time a host reconnects to the lockspace
-    sl.acquireHostId(HOST_ID, async=False)
-    sl.acquire(HOST_ID, LEASE)
-    sl.releaseHostId(HOST_ID, async=False, unused=True)
-    sl.acquireHostId(HOST_ID, async=False)
-    version, owner = sl.inquire(LEASE)
+    lock.acquireHostId(HOST_ID, wait=True)
+    lock.acquire(HOST_ID, LEASE)
+    lock.releaseHostId(HOST_ID, wait=True, unused=True)
+    lock.acquireHostId(HOST_ID, wait=True)
+    version, owner = lock.inquire(LEASE)
     assert version == 0
     assert owner is None
 
 
-def test_inquire_smaller_host_generation(fake_sanlock):
-    sl = clusterlock.SANLock(LS_NAME, LS_PATH, LEASE)
-    sl.acquireHostId(HOST_ID, async=False)
-    sl.releaseHostId(HOST_ID, async=False, unused=True)
-    sl.acquireHostId(HOST_ID, async=False)
-    sl.acquire(HOST_ID, LEASE)
+def test_inquire_smaller_host_generation(fake_sanlock, lock):
+    lock.acquireHostId(HOST_ID, wait=True)
+    lock.releaseHostId(HOST_ID, wait=True, unused=True)
+    lock.acquireHostId(HOST_ID, wait=True)
+    lock.acquire(HOST_ID, LEASE)
     # Setting the host generation to be smaller than the
     # generation on the lease (an invalid state), the
     # lease should have no owner
     fake_sanlock.hosts[HOST_ID]["generation"] = 0
-    version, owner = sl.inquire(LEASE)
+    version, owner = lock.inquire(LEASE)
     assert version == 0
     assert owner is None
 
 
-def test_inquire_lease_has_no_owner(fake_sanlock):
-    sl = clusterlock.SANLock(LS_NAME, LS_PATH, LEASE)
-    sl.acquireHostId(HOST_ID, async=False)
-    version, owner = sl.inquire(LEASE)
+def test_inquire_lease_has_no_owner(fake_sanlock, lock):
+    lock.acquireHostId(HOST_ID, wait=True)
+    version, owner = lock.inquire(LEASE)
     assert version is None
     assert owner is None
 
